mythicbeasts
    * ``auth_username`` Specify api credentials username

    * ``auth_password`` Specify api credentials password

    * ``auth_token`` Specify api token for authentication


.. note::
   
   There are two ways to provide an authentication granting access to the Mythic Beasts API
   1 - With your API credentials (user/password), using --auth-username and --auth-password flags.
   2 - With an API token, using --auth-token flags.
   These credentials and tokens must be generated using the Mythic Beasts API v2.
   

